@@ -40,6 +40,6 @@ SEXP R_ssh_new_file_writer(SEXP path){
   return ptr;
 }
 
-SEXP R_ssh_total_writers(){
+SEXP R_ssh_total_writers(void){
   return(ScalarInteger(total_open_writers));
 }
